@@ -1,15 +1,13 @@
-context("session")
-
 test_that("object", {
   x <- runif(10)
   d <- session_encrypt(x)
-  expect_is(d, "function")
+  expect_type(d, "closure")
   expect_identical(d(), x)
 
   ## Do not include sensitive information:
   e <- environment(d)
   expect_equal(ls(e, all.names = TRUE), "data") # in particular no 'key'
-  expect_is(attr(e$data, "nonce", exact = TRUE), "raw")
+  expect_type(attr(e$data, "nonce", exact = TRUE), "raw")
 
   ## Environment chain includes nothing sensitive:
   expect_identical(parent.env(e), environment(session_encrypt))
@@ -18,13 +16,13 @@ test_that("object", {
 test_that("raw", {
   y <- sodium::keygen()
   d <- session_encrypt(y)
-  expect_is(d, "function")
+  expect_type(d, "closure")
   expect_identical(d(), y)
 
   ## Do not include sensitive information:
   e <- environment(d)
   expect_equal(ls(e, all.names = TRUE), "data") # in particular no 'key'
-  expect_is(attr(e$data, "nonce", exact = TRUE), "raw")
+  expect_type(attr(e$data, "nonce", exact = TRUE), "raw")
 
   ## Environment chain includes nothing sensitive:
   expect_identical(parent.env(e), environment(session_encrypt))
