@@ -1,5 +1,3 @@
-context("ssh_keygen")
-
 test_that("keygen", {
   path <- tempfile()
   res <- ssh_keygen(path, "secret")
@@ -7,8 +5,8 @@ test_that("keygen", {
   expect_true(is_directory(path))
   expect_true(file.exists(file.path(path, "id_rsa")))
   expect_true(file.exists(file.path(path, "id_rsa.pub")))
-  expect_is(keypair_openssl(path, path, password = "secret"),
-            "cyphr_keypair")
+  expect_s3_class(keypair_openssl(path, path, password = "secret"),
+                  "cyphr_keypair")
 })
 
 test_that("shell", {
@@ -20,8 +18,8 @@ test_that("shell", {
   expect_true(is_directory(path))
   expect_true(file.exists(file.path(path, "id_rsa")))
   expect_true(file.exists(file.path(path, "id_rsa.pub")))
-  expect_is(keypair_openssl(path, path, password = "secret"),
-            "cyphr_keypair")
+  expect_s3_class(keypair_openssl(path, path, password = "secret"),
+                  "cyphr_keypair")
 })
 
 test_that("existing, but not directory", {
@@ -43,7 +41,7 @@ test_that("existing, but not directory", {
 test_that("no password", {
   path <- tempfile()
   res <- ssh_keygen(path, FALSE)
-  expect_is(openssl_load_key(path, ""), "key")
+  expect_s3_class(openssl_load_key(path, ""), "key")
 })
 
 test_that("no password - shell", {
@@ -52,7 +50,7 @@ test_that("no password - shell", {
   skip_on_os("windows") # not working on windows gha
   path <- tempfile()
   res <- ssh_keygen(path, FALSE, TRUE)
-  expect_is(openssl_load_key(path, ""), "key")
+  expect_s3_class(openssl_load_key(path, ""), "key")
 })
 
 test_that("invalid password", {
@@ -61,9 +59,9 @@ test_that("invalid password", {
 
 test_that("get password", {
   path <- tempfile()
-  testthat::with_mock(
-    `cyphr::get_password_str` = function(...) "secret",
+  testthat::with_mocked_bindings(
+    get_password_str = function(...) "secret",
     ssh_keygen(path, TRUE))
   expect_error(openssl_load_key(path, "wrong password"))
-  expect_is(openssl_load_key(path, "secret"), "key")
+  expect_s3_class(openssl_load_key(path, "secret"), "key")
 })
