@@ -1,5 +1,3 @@
-context("data workflow")
-
 test_that("missing user key throws error", {
   expect_error(data_load_keypair_user(tempfile()),
                "key does not exist")
@@ -7,7 +5,7 @@ test_that("missing user key throws error", {
 
 test_that("load and reload openssl keypair", {
   pair <- data_load_keypair_user("pair1")
-  expect_is(pair, "cyphr_keypair")
+  expect_s3_class(pair, "cyphr_keypair")
   expect_identical(data_load_keypair_user(pair), pair)
 })
 
@@ -35,35 +33,36 @@ test_that("initialisation", {
   path <- tempfile()
   dir.create(path, FALSE, TRUE)
   quiet <- FALSE
-  res <- data_admin_init(path, "pair1", quiet)
-  expect_is(res, "cyphr_key")
+  res <- suppressMessages(data_admin_init(path, "pair1", quiet))
+  expect_s3_class(res, "cyphr_key")
   expect_true(file.exists(data_path_cyphr(path)))
   expect_true(file.exists(data_path_test(path)))
   expect_identical(decrypt_string(data_path_test(path), res), "cyphr")
 
   keys <- data_admin_list_keys(path)
   expect_equal(length(keys), 1L)
-  expect_is(keys, "data_keys")
+  expect_s3_class(keys, "data_keys")
   expect_identical(keys[[1]]$pub, data_load_keypair_user("pair1")$pub)
 
-  expect_message(data_request_access(path, "pair1"),
-                 "You appear to already have access")
+  msg <- capture_messages(data_request_access(path, "pair1"))
+  expect_match(msg, "You appear to already have access")
 
-  expect_message(data_admin_init(path, "pair1", quiet),
-                 "Already set up")
+  msg <- capture_messages(data_admin_init(path, "pair1", quiet))
+  expect_match(msg[[1]], "Already set up")
 })
 
 test_that("grant access", {
   path <- tempfile()
   dir.create(path, FALSE, TRUE)
   quiet <- FALSE
-  res <- data_admin_init(path, "pair1", quiet)
+  res <- data_admin_init(path, "pair1", quiet = TRUE)
   r <- runif(10)
   encrypt_object(r, res, file.path(path, "data.rds"))
 
-  h <- data_request_access(path, "pair2", quiet)
-  expect_message(h2 <- data_request_access(path, "pair2", quiet),
-                 "already pending")
+  h <- data_request_access(path, "pair2", quiet = TRUE)
+  msg <- capture_messages(h2 <- data_request_access(path, "pair2", quiet))
+
+  expect_match(msg[[1]], "already pending")
   expect_identical(h2, h)
 
   pair2 <- data_load_keypair_user("pair2")
@@ -76,10 +75,11 @@ test_that("grant access", {
   expect_identical(dat_req$pub, pair2$pub)
   expect_identical(dat_req$host, Sys.info()[["nodename"]])
   expect_identical(dat_req$user, Sys.info()[["user"]])
-  expect_is(dat_req$date, "POSIXt")
+  expect_s3_class(dat_req$date, "POSIXt")
 
   ## Try loading requests:
-  keys <- data_load_request(path, NULL, quiet)
+  expect_message(keys <- data_load_request(path, NULL, quiet),
+                 "There is 1 request for access")
   tmp <- keys[[1]]
   tmp$filename <- NULL
   expect_identical(tmp, dat_req)
@@ -94,11 +94,11 @@ test_that("grant access", {
   expect_error(data_load_request(path, TRUE),
                "Invalid type for 'hash'")
 
-  ans <- data_admin_authorise(path, h, "pair1", TRUE, quiet)
+  ans <- data_admin_authorise(path, h, "pair1", TRUE, quiet = TRUE)
 
   ## Then the new user can connect:
   k <- data_key(path, "pair2")
-  expect_is(k, "cyphr_key")
+  expect_s3_class(k, "cyphr_key")
   expect_identical(k$key(), res$key())
 
   expect_identical(decrypt_object(file.path(path, "data.rds"), k), r)
@@ -109,7 +109,7 @@ test_that("git messages", {
   dir.create(path, FALSE, TRUE)
   dir.create(file.path(path, ".git"), FALSE, TRUE)
   quiet <- FALSE
-  res <- data_admin_init(path, "pair1", quiet)
+  res <- data_admin_init(path, "pair1", quiet = TRUE)
 
   res <- testthat::evaluate_promise(data_request_access(path, "pair2", quiet))
   expect_match(res$messages, "If you are using git", all = FALSE)
@@ -129,7 +129,7 @@ test_that("not set up", {
   expect_error(
     with_dir(path, data_key(path_user = "pair2")),
     "cyphr not set up for")
-  res <- data_admin_init(path, "pair1")
+  res <- data_admin_init(path, "pair1", quiet = TRUE)
   expect_error(data_key(path, "pair2"),
                "Key file not found; you may not have access")
 })
@@ -137,38 +137,41 @@ test_that("not set up", {
 test_that("authorise no keys", {
   path <- tempfile()
   dir.create(path, FALSE, TRUE)
-  res <- data_admin_init(path, "pair1")
-  expect_message(data_admin_authorise(path, path_user = "pair1"),
-                 "No keys to add")
+  res <- data_admin_init(path, "pair1", quiet = TRUE)
+  msg <- capture_messages(data_admin_authorise(path, path_user = "pair1"))
+  expect_match(msg[[1]], "There is 0 requests for access")
+  expect_match(msg[[2]], "No keys to add")
 })
 
 test_that("cancel auth", {
   path <- tempfile()
   dir.create(path, FALSE, TRUE)
-  res <- data_admin_init(path, "pair1")
-  h <- data_request_access(path, "pair2")
+  res <- data_admin_init(path, "pair1", quiet = TRUE)
+  h <- data_request_access(path, "pair2", quiet = TRUE)
 
-  testthat::with_mock(
-    `cyphr:::prompt_confirm` = function() FALSE,
-    expect_message(try(data_admin_authorise(path, h, "pair1", FALSE),
-                       silent = TRUE),
-                   "Cancelled adding key"),
-    expect_error(data_admin_authorise(path, h, "pair1", FALSE),
-                 "Errors adding 1 key"))
+  testthat::with_mocked_bindings(
+    prompt_confirm = function() FALSE, {
+      msg <- capture_messages(
+        try(data_admin_authorise(path, h, "pair1", FALSE), silent = TRUE))
+      expect_match(msg, "Cancelled adding key", all = FALSE)
+      expect_error(
+        suppressMessages(data_admin_authorise(path, h, "pair1", quiet = TRUE)),
+        "Errors adding 1 key")
+    })
 })
 
 test_that("print keys", {
   path <- tempfile()
   dir.create(path, FALSE, TRUE)
-  res <- data_admin_init(path, "pair1")
+  res <- data_admin_init(path, "pair1", quiet = TRUE)
 
   expect_output(print(data_admin_list_requests(path)), "(empty)",
                 fixed = TRUE)
   msg <- capture.output(print(data_admin_list_keys(path)))
   expect_match(msg[[1]], "1 key:")
 
-  h <- data_request_access(path, "pair2")
-  ans <- data_admin_authorise(path, h, "pair1", TRUE)
+  h <- data_request_access(path, "pair2", quiet = TRUE)
+  ans <- data_admin_authorise(path, h, "pair1", TRUE, quiet = TRUE)
 
   msg <- capture.output(print(data_admin_list_keys(path)))
   expect_match(msg[[1]], "2 keys:")
@@ -177,10 +180,10 @@ test_that("print keys", {
 test_that("detect tampering", {
   path <- tempfile()
   dir.create(path, FALSE, TRUE)
-  res <- data_admin_init(path, "pair1")
+  res <- data_admin_init(path, "pair1", quiet = TRUE)
 
   ## Here's the request:
-  h <- data_request_access(path, "pair2")
+  h <- data_request_access(path, "pair2", quiet = TRUE)
 
   ## Here's the attacker:
   pair3 <- data_load_keypair_user("pair3")
@@ -203,8 +206,8 @@ test_that("decryption failed gives reasonable error", {
   path2 <- tempfile()
   dir.create(path1, FALSE, TRUE)
   dir.create(path2, FALSE, TRUE)
-  res1 <- data_admin_init(path1, "pair1")
-  res2 <- data_admin_init(path2, "pair1")
+  res1 <- data_admin_init(path1, "pair1", quiet = TRUE)
+  res2 <- data_admin_init(path2, "pair1", quiet = TRUE)
   file.copy(data_path_test(path1), data_path_test(path2), overwrite = TRUE)
   expect_error(data_key(path2, "pair1"),
                "Decryption failed")
@@ -213,10 +216,12 @@ test_that("decryption failed gives reasonable error", {
 test_that("gracefully fail to initialise", {
   path <- tempfile()
   dir.create(path, FALSE, TRUE)
-  testthat::with_mock(
-    `cyphr:::data_authorise_write` = function(...) stop("Unexplained error"),
-    expect_message(try(data_admin_init(path, "pair1"), silent = TRUE),
-                   "Removing data key"))
+  testthat::with_mocked_bindings(
+    data_authorise_write = function(...) stop("Unexplained error"), {
+      msg <- capture_messages(
+        try(data_admin_init(path, "pair1"), silent = TRUE))
+      expect_match(msg, "Removing data key", all = FALSE)
+    })
   expect_equal(dir(data_path_cyphr(path), all.files = TRUE, no.. = TRUE),
                character(0))
 })
@@ -228,7 +233,7 @@ test_that("gracefully fail to initialise", {
 test_that("Work from a subdirectory", {
   path <- tempfile()
   dir.create(path, FALSE, TRUE)
-  res <- data_admin_init(path, "pair1", TRUE)
+  res <- data_admin_init(path, "pair1", quiet = TRUE)
   sub <- file.path(path, "a/b/c")
   dir.create(sub, FALSE, TRUE)
   ## Need full paths to keys as they will be in a surprising location
@@ -237,14 +242,14 @@ test_that("Work from a subdirectory", {
   pair2 <- normalizePath("pair2")
 
   h <- with_dir(sub,
-                data_request_access(path_user = pair2))
+                data_request_access(path_user = pair2, quiet = TRUE))
 
   res <- with_dir(sub, data_admin_list_requests())
   expect_equal(length(res), 1L)
   expect_equal(names(res), unclass(as.character(h)))
 
   with_dir(sub,
-           data_admin_authorise(path_user = pair1, yes = TRUE))
+           data_admin_authorise(path_user = pair1, yes = TRUE, quiet = TRUE))
 
   res <- with_dir(sub, data_admin_list_keys())
   expect_equal(length(res), 2L)
@@ -258,7 +263,7 @@ test_that("Work from a subdirectory", {
 test_that("Custom messages", {
   path <- tempfile()
   dir.create(path, FALSE, TRUE)
-  res <- data_admin_init(path, "pair1", TRUE)
+  res <- data_admin_init(path, "pair1", quiet = TRUE)
 
   writeLines("my custom $HASH request message",
              file.path(data_path_template(path), "request"))
@@ -313,7 +318,7 @@ test_that("migrate", {
   path_openssl_bob <- file.path(path, "openssl", "bob")
   suppressWarnings(data_version_read(path_data))
 
-  data_request_access(path_data, "pair3")
+  data_request_access(path_data, "pair3", quiet = TRUE)
 
   keys_old <- data_admin_list_keys(path_data)
   reqs_old <- data_admin_list_requests(path_data)
@@ -325,8 +330,9 @@ test_that("migrate", {
   keys_new <- data_admin_list_keys(path_data)
   reqs_new <- data_admin_list_requests(path_data)
 
-  map <- vapply(keys_old, function(k)
-    bin2str(data_key_fingerprint(k$pub, data_schema_version()), ""), "")
+  map <- vapply(keys_old, function(k) {
+    bin2str(data_key_fingerprint(k$pub, data_schema_version()), "")
+  }, "")
 
   expect_setequal(names(keys_new), unname(map))
   v <- c("user", "host", "date", "pub", "key")
@@ -339,7 +345,8 @@ test_that("migrate", {
   expect_identical(key1$key(), key2$key())
 
   data_admin_list_requests(path_data)
-  data_admin_authorise(path_data, path_user = path_openssl_alice, yes = TRUE)
+  data_admin_authorise(path_data, path_user = path_openssl_alice, yes = TRUE,
+                       quiet = TRUE)
   key3 <- data_key(path_data, "pair3")
 
   expect_identical(key1$key(), key3$key())
@@ -352,7 +359,7 @@ test_that("migrate", {
 test_that("schema validation - new version errors", {
   path <- tempfile()
   dir.create(path, FALSE)
-  res <- data_admin_init(path, "pair1")
+  res <- data_admin_init(path, "pair1", quiet = TRUE)
   writeLines("9.9.9", data_path_version(path))
   data_pkg_init() # clear cache
   expect_error(
@@ -365,7 +372,7 @@ test_that("schema validation - new version errors", {
 test_that("new data sources do not need migrating", {
   path <- tempfile()
   dir.create(path, FALSE)
-  data_admin_init(path, "pair1")
+  data_admin_init(path, "pair1", quiet = TRUE)
   res <- testthat::evaluate_promise(data_schema_migrate(path))
   expect_match(res$messages, "Everything up to date!")
 })
@@ -374,7 +381,7 @@ test_that("new data sources do not need migrating", {
 test_that("cache data key", {
   path <- tempfile()
   dir.create(path, FALSE)
-  data_admin_init(path, "pair1")
+  data_admin_init(path, "pair1", quiet = TRUE)
 
   key1 <- data_key(path, "pair1")
   key2 <- data_key(path, "pair1")
